<?php

/***************************************************************
*
* Description-Plugin für moziloCMS.
* 
* Details: http://software.azett.com
* 
***************************************************************/

class MetaDescription extends Plugin {
    
    function getContent($value) {
    
        // Aktuell vorhandene Inhaltsseiten einlesen
        if ($this->settings->get("initialize") == "true") {
            $this->initialize();
        }

        $descriptions_as_properties = $this->getDescriptionsAsProperties();
        $description = $this->getDescriptionForCurrentPage($descriptions_as_properties);
        // Temp-Datei wieder leeren
        fopen("plugins/MetaDescription/descriptions.tmp", 'w');
        return $description;
        
    } // function getContent
    
    function getConfig() {
        $config = array();

        $config['descriptions'] = array(
            "type" => "textarea",                       // Pflicht:  Eingabetyp 
            "cols" => "100",                             // Pflicht:  Spaltenanzahl 
            "rows" => "10",                              // Pflicht:  Zeilenanzahl
            "description" => "Meta-Descriptions der einzelnen Inhaltsseiten<br />(Kategorie:Inhaltsseite&nbsp;=&nbsp;Beschreibung)",                // Pflicht:  Beschreibung
            "regex" => "/^.+=.+$/"                      // optional: Erlaubte Werte als regulärer Ausdruck (hier: wenigstens ein Zeichen; wird beim Speichern der Einstellungen überprüft)
        );
        $config['initialize'] = array(
            "type" => "checkbox",
            "description" => "Inhaltsseiten neu einlesen <br />(vorhandene&nbsp;Werte&nbsp;bleiben&nbsp;erhalten)"
        );
        
        return $config;
    } // function getConfig
    
    function getInfo() {
            $info = array(
            // Plugin-Name + Version
            "<b>MetaDescription</b> 1.2.2010-10-20",
            // moziloCMS-Version
            "1.12",
            // Kurzbeschreibung nur <span> und <br /> sind erlaubt
            "Eigene Meta-Description für jede Inhaltsseite",
            // Name des Autors
            "Arvid Zimmermann",
            // Download-URL
            "http://software.azett.com",
            // Platzhalter für die Selectbox in der Editieransicht 
            // - ist das Array leer, erscheint das Plugin nicht in der Selectbox
            array()
        );
        return $info;
    } // function getInfo
    
    // Hilfsfunktion: Textarea-Inhalt als Properties-Objekt zurückgeben
    function getDescriptionsAsProperties() {
        $descriptions_as_array = explode("<br />", $this->settings->get("descriptions"));
        $descriptions_as_properties = new Properties("plugins/MetaDescription/descriptions.tmp");
        foreach ($descriptions_as_array as $currentline) {
            // Zeile am ersten "=" aufsplitten
            $equalpos = strpos($currentline, "=");
            if ($equalpos > 0) {
                $currentvalue = trim(substr($currentline, $equalpos+1, strlen($currentline)-$equalpos));
                $currentkey = trim(substr($currentline, 0, $equalpos));
                $descriptions_as_properties->set($currentkey, $currentvalue);
            }
        }
        return $descriptions_as_properties;
    }

    // Hilfsfunktion: Properties-Objekt in die Plugin-Settings speichern
    function setDescriptionsFromProperties($descriptions) {
        $descriptions_as_array = $descriptions->toArray();
        $descriptions = "";
        foreach ($descriptions_as_array as $currentkey => $currentvalue) {
            if ($currentkey != "readonly") {
                $descriptions = $descriptions . $currentkey . " = " . $currentvalue . "<br />";
            }
        }
        $this->settings->set("descriptions", $descriptions);
    }
    
    // Hilfsfunktion: Descriptions für aktuelle Inhaltsseite zurückgeben
    function getDescriptionForCurrentPage($descriptions_as_properties) {
        global $CAT_REQUEST;
        global $PAGE_REQUEST;
        global $specialchars;
        global $CMS_CONF;
        global $CatPage;
        
        $currentcat = $CatPage->get_HrefText($CAT_REQUEST, false);
        $currentpage = $CatPage->get_HrefText($CAT_REQUEST,$PAGE_REQUEST);
        if ($descriptions_as_properties->keyExists($currentcat.":".$currentpage)) {
            $currentdesc = $descriptions_as_properties->get($currentcat.":".$currentpage);
            if ($currentdesc != "") {
                return $currentdesc;
            }
        }
        return $specialchars->rebuildSpecialChars($CMS_CONF->get("websitedescription"),false,true);
    } 
    
    
    function initialize() {
        global $CatPage;
        
        $descriptions_as_properties = $this->getDescriptionsAsProperties();
        $changed = false;

        foreach ($CatPage->get_CatArray(false,false,array(EXT_PAGE,EXT_HIDDEN)) as $cat) {
            foreach ($CatPage->get_PageArray($cat,array(EXT_PAGE,EXT_HIDDEN),true) as $page) {
                $keyToCheck = $CatPage->get_HrefText($cat,false). ":" .$CatPage->get_HrefText($cat,$page);
                if (!$descriptions_as_properties->keyExists($keyToCheck)) {
                    $descriptions_as_properties->set($keyToCheck, "");
                    $changed = true;
                }
            }
        }
        if ($changed) {
            $this->setDescriptionsFromProperties($descriptions_as_properties);
        }
        $this->settings->set("initialize", "false");
    }
}

?>